# Changelog

<!--next-version-placeholder-->

## v0.1.1 (2024-02-05)
### Fix
* **pip:** Since pip.compile 0.5.x, wl.compile is deprecated! ([`1736c2d`](https://github.com/educationwarehouse/edwh-whitelabel-plugin/commit/1736c2d797f638e08f9101b4fbde5344bf7c3b3b))

## v0.1.0 (2023-11-03)
### Feature
* EOD WIP; whitelabel-specific pip compile ([`09a922b`](https://github.com/educationwarehouse/edwh-whitelabel-plugin/commit/09a922b2a0d2988245ea9eadcadbf138214684f1))

### Fix
* Use new `get_task` function and updated pip_* function ([`b3372b6`](https://github.com/educationwarehouse/edwh-whitelabel-plugin/commit/b3372b69739b349d431184a7937e364bde9026aa))
* Changed namespace to `wl` because Remco was right and we are lazy ([`a0a37c3`](https://github.com/educationwarehouse/edwh-whitelabel-plugin/commit/a0a37c3e41a49b2f662eb0e0f5062533c850d80d))

## v0.0.1 (2023-10-31)
